package de.intevation.flys.client.client;

import com.google.gwt.core.client.EntryPoint;
import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.RootPanel;

import com.smartgwt.client.widgets.layout.VLayout;

import de.intevation.artifacts.common.model.User;

import de.intevation.flys.client.client.services.UserService;
import de.intevation.flys.client.client.services.UserServiceAsync;
import de.intevation.flys.client.client.ui.FLYSView;
import de.intevation.flys.client.client.ui.MainMenu;
import de.intevation.flys.client.client.ui.ProjectList;


/**
 * Entry point classes define <code>onModuleLoad()</code>.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class FLYS implements EntryPoint {

    /** The UserService used to retrieve information about the current user. */
    protected UserServiceAsync userService = GWT.create(UserService.class);

    /** The menu bar at the top of the application.*/
    protected MainMenu menu;

    /** The content window. It takes the whole space beneath the menu bar.*/
    protected FLYSView view;

    /** The project list that displays the projects of the user.*/
    protected ProjectList projectList;


    /**
     * This is the entry point method.
     */
    public void onModuleLoad() {

        VLayout vertical = new VLayout();
        vertical.setMembersMargin(2);
        vertical.setLayoutMargin(1);
        vertical.setWidth100();
        vertical.setHeight100();

        menu = new MainMenu();
        view = new FLYSView();

        vertical.addMember(menu);
        vertical.addMember(view);

        RootPanel.get("app").add(vertical);

        userService.getCurrentUser(new AsyncCallback<User>() {
            public void onFailure(Throwable caught) {
                GWT.log("Could not find a logged in user.");
                // TODO do something
            }

            public void onSuccess(User user) {
                GWT.log("Found a user. Set '"+ user.getLastName()+"'");
                menu.setCurrentUser(user);

                projectList = new ProjectList(user);
                view.setProjectList(projectList);
            }
        });
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
